@@ -49,7 +49,7 @@ With Lemonldap::NG::Portal::Simple:
 
   use Lemonldap::NG::Portal::Simple;
   my $portal = new Lemonldap::NG::Portal::Simple(
-         domain         => 'gendarmerie.defense.gouv.fr',
+         domain         => 'example.com',
          globalStorage  => 'Apache::Session::MySQL',
          globalStorageOptions => {
            DataSource   => 'dbi:mysql:database',
@@ -104,6 +104,16 @@ http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
 
 Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://forge.objectweb.org/tracker/?group_id=274>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2005-2007 by Xavier Guimard E<lt>x.guimard@free.frE<gt>
